==> php-residence_0.2.4.tar.gz: php-residence/inizio.php <==
<html>
<header>
<title> Pagina di entrata per php-residence </title>
</header>
<body bgcolor=#ffffff>
<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#################################################################################



include("includes/funzioni.php");
$pag = "inizio.php";

if ($creaanno) {
include("creaanno.php");
echo "<br> ".mex("Anno ",$pag).$anno.mex(" creato",$pag)."! <br><br>
<form method=\"post\" action=\"inizio.php?anno=$anno\">
<input type=\"submit\" name=\"ok\" value=\"OK\"><br>
</form>";

} # fine if ($creaanno)

else {

# Controllo se sonostati inseriti i dati permanenti.
if (is_file("dati/connessione_db.php") != true) {
echo "
<center><font size=+2><b>Welcome to PHP-RESIDENCE.</b></font><br><br>
PHP-RESIDENCE version 0.2.4, Copyright (C) 2001-2002 Marco M. F. De Santis<br>
Php-residence comes with ABSOLUTELY NO WARRANTY; <br>for details see the file 
<a href=\"COPYING\">COPYING</a>. <br> This is free software, and you are 
welcome to redistribute it<br>
 under certain conditions; see the  file 
<a href=\"COPYING\">COPYING</a> for details.<br>
</center><hr width=\"95%\">
<br><br>
<form method=\"post\" action=\"creadb.php\">
Choose the language:
 <select name=\"lingua\">
<option value=\"en\">english</option>
<option value=\"ita\">italiano</option>
<!-- <option value=\"es\">espaol</option> -->
</select><br>
<input type=\"submit\" name=\"crealo\" value=\"create database\"><br>
</form>";
} # fine if (is_file("dati/connessione_db.php") != true)

else {

# Se non si specifica nessun anno uso l'attuale
if ( $anno == "" ) {
$anno = date("Y");
}

#$anno = ereg_replace($SCRIPT_NAME."/","",$REQUEST_URI);
#$anno = ereg_replace($SCRIPT_NAME,"",$anno);

if ( is_file("dati/selectperiodi$anno.php")) {
//esiste l'anno richiesto
$anno_succ = $anno + 1;
echo "<br><center><font size=+2><strong>".mex("Men principale dell'anno",$pag)." 
$anno</font></strong> <br>";
echo "<P><br>
<form method=\"post\" action=\"prenota.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"prenota\" value=\"".mex("Inserisci una nuova prenotazione",$pag)."\"><br>
</form>
<form method=\"post\" action=\"tabella.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<table cellspacing=0 cellpadding=0><tr><td>
<input type=\"submit\" name=\"prenota\" value=\"".mex("Visualizza e modifica le prenotazioni",$pag)."\">
 ".mex("del mese di",$pag);
$mese_attuale = date("n");
for ($num1 = 1 ; $num1 <= 12 ; $num1++) {
$mese_invia[$num1] = "\"$num1\"";
if ($num1 == $mese_attuale) $mese_invia[$num1] .= " selected";
$mese_invia[$num1] .= ">";
} # fine for $num1
echo " <select name=\"mese\">
<option value=".$mese_invia[1].mex("Gennaio",$pag)."</option>
<option value=".$mese_invia[2].mex("Febbraio",$pag)."</option>
<option value=".$mese_invia[3].mex("Marzo",$pag)."</option>
<option value=".$mese_invia[4].mex("Aprile",$pag)."</option>
<option value=".$mese_invia[5].mex("Maggio",$pag)."</option>
<option value=".$mese_invia[6].mex("Giugno",$pag)."</option>
<option value=".$mese_invia[7].mex("Luglio",$pag)."</option>
<option value=".$mese_invia[8].mex("Agosto",$pag)."</option>
<option value=".$mese_invia[9].mex("Settembre",$pag)."</option>
<option value=".$mese_invia[10].mex("Ottobre",$pag)."</option>
<option value=".$mese_invia[11].mex("Novembre",$pag)."</option>
<option value=".$mese_invia[12].mex("Dicembre",$pag)."</option>
</select></td><td>
<input type=\"radio\" name=\"anno_succ\" value=\"NO\" checked>$anno<br>
<input type=\"radio\" name=\"anno_succ\" value=\"SI\">$anno_succ
</td></tr></table>
</form>
<form method=\"post\" action=\"visualizza_tabelle.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"visualizza\" value=\"".mex("Visualizza la tabella",$pag)."\">
 ".mex("con",$pag)."
<select name=\"tipo_tabella\">
<option value=\"prenotazioni\">".mex("tutte le prenotazioni",$pag)."</option>
<option value=\"costi\">".mex("le spese e le entrate",$pag)."</option>
<option value=\"periodi\">".mex("i periodi e le tariffe",$pag)."</option>
<option value=\"clienti\">".mex("tutti i clienti",$pag)."</option>
<option value=\"regole\">".mex("le regole di assegnazione",$pag)."</option>
<option value=\"appartamenti\">".mex("tutti gli appartamenti",$pag)."</option>
</select>
<br>
</form>
<form method=\"post\" action=\"clienti.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"clienti\" value=\"".mex("Inserisci o modifica i dati di un cliente",$pag)."\"><br>
</form>
<form method=\"post\" action=\"costi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"ins_costi\" value=\"".mex("Inserisci le spese e le entrate",$pag)."\"><br>
</form>
<form method=\"post\" action=\"disponibilita.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"con_dis\" value=\"".mex("Controlla la disponibilit",$pag)."\">
 ".mex("dal",$pag)." <select name=\"inizioperiodo\">";
include("dati/selperiodimenu$anno.php");
echo "</select>
 ".mex("al",$pag)." <select name=\"fineperiodo\">";
include("dati/selperiodimenu$anno.php");
echo "</select> (".mex("per",$pag)."
 <input type=\"text\" name=\"numpersone\" size=\"2\" maxlength=\"2\">
 ".mex("persone",$pag).")
</form>
<hr width=\"95%\">
<form method=\"post\" action=\"creaprezzi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"insprezzi\" value=\"".mex("Inserisci o modifica i prezzi",$pag)."\">
</form>
<form method=\"post\" action=\"crearegole.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"insregole\" value=\"".mex("Inserisci o modifica le regole di assegnazione",$pag)."\"><br>
</form>
<form method=\"post\" action=\"personalizza.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"insregole\" value=\"".mex("Personalizza",$pag)."\"><br>
</form>
<form method=\"post\" action=\"inizio.php\">
".mex("richiedi l'anno",$pag)."
<input type=\"text\" name=\"anno\" size=\"4\" maxlength=\"4\">
<input type=\"submit\" name=\"vai\" value=\"".mex("vai",$pag)."\"><br>
</form>";


} # fine if ( is_dir($anno))

else {

# Non esiste l'anno richiesto

if (controlla_anno($anno) == "NO") echo mex("Il formato dell'anno richiesto  sbagliato",$pag).".<br>";
else {

echo "<br> ".mex("Non esiste l'anno ",$pag).$anno.mex(" nel database",$pag).". <br><br>
<form method=\"post\" action=\"inizio.php?anno=$anno\">
<input type=\"submit\" name=\"creaanno\" value=\"".mex("Crea l'anno",$pag)." $anno \">
 ".mex("con periodi",$pag).":<br>
<input type=\"radio\" name=\"tipo_periodi\" value=\"s\" checked>
".mex("settimanali",$pag)." (
 <select name=\"giorno_ini_fine\">
<option value=\"0\">".mex("Domenica",$pag)."</option>
<option value=\"1\">".mex("Luned",$pag)."</option>
<option value=\"2\">".mex("Marted",$pag)."</option>
<option value=\"3\">".mex("Mercoled",$pag)."</option>
<option value=\"4\">".mex("Gioved",$pag)."</option>
<option value=\"5\">".mex("Venerd",$pag)."</option>
<option value=\"6\" selected>".mex("Sabato",$pag)."</option>
</select> ".mex("come giorno di inizio/fine locazione",$pag).")<br>
<input type=\"radio\" name=\"tipo_periodi\" value=\"g\">
".mex("giornalieri",$pag)."<br>
".mex("e prenotazioni da",$pag)."
 <select name=\"mese_ini\">
<option value=\"1\" selected>".mex("Gennaio",$pag)."</option>
<option value=\"2\">".mex("Febbraio",$pag)."</option>
<option value=\"3\">".mex("Marzo",$pag)."</option>
<option value=\"4\">".mex("Aprile",$pag)."</option>
<option value=\"5\">".mex("Maggio",$pag)."</option>
<option value=\"6\">".mex("Giugno",$pag)."</option>
<option value=\"7\">".mex("Luglio",$pag)."</option>
<option value=\"8\">".mex("Agosto",$pag)."</option>
<option value=\"9\">".mex("Settembre",$pag)."</option>
<option value=\"10\">".mex("Ottobre",$pag)."</option>
<option value=\"11\">".mex("Novembre",$pag)."</option>
<option value=\"12\">".mex("Dicembre",$pag)."</option>
</select> ".mex("a",$pag)."
 <select name=\"mese_fine\">
<option value=\"1\">".mex("Gennaio",$pag)."</option>
<option value=\"2\">".mex("Febbraio",$pag)."</option>
<option value=\"3\">".mex("Marzo",$pag)."</option>
<option value=\"4\">".mex("Aprile",$pag)."</option>
<option value=\"5\">".mex("Maggio",$pag)."</option>
<option value=\"6\">".mex("Giugno",$pag)."</option>
<option value=\"7\">".mex("Luglio",$pag)."</option>
<option value=\"8\">".mex("Agosto",$pag)."</option>
<option value=\"9\">".mex("Settembre",$pag)."</option>
<option value=\"10\">".mex("Ottobre",$pag)."</option>
<option value=\"11\">".mex("Novembre",$pag)."</option>
<option value=\"12\" selected>".mex("Dicembre",$pag)."</option>
<option value=\"13\">".mex("Gen. anno successivo",$pag)."</option>
<option value=\"14\">".mex("Feb. anno successivo",$pag)."</option>
<option value=\"15\">".mex("Mar. anno successivo",$pag)."</option>
<option value=\"16\">".mex("Apr. anno successivo",$pag)."</option>
<option value=\"17\">".mex("Mag. anno successivo",$pag)."</option>
<option value=\"18\">".mex("Giu. anno successivo",$pag)."</option>
<option value=\"19\">".mex("Lug. anno successivo",$pag)."</option>
<option value=\"20\">".mex("Ago. anno successivo",$pag)."</option>
<option value=\"21\">".mex("Set. anno successivo",$pag)."</option>
<option value=\"22\">".mex("Ott. anno successivo",$pag)."</option>
<option value=\"23\">".mex("Nov. anno successivo",$pag)."</option>
<option value=\"24\">".mex("Dic. anno successivo",$pag)."</option>
<option value=\"25\">".mex("Gen. 2 anni successivi",$pag)."</option>
</select>.<br>";
$anno_prec = $anno -1;
if ( is_file("dati/selectperiodi$anno_prec.php")) {
echo "<input type=\"checkbox\" name=\"importa_anno_prec\" value=\"SI\" checked>
".mex("Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi) e 
regole d'assegnazione relative a quest'anno.",$pag);
} # fine if ( is_file("dati/selectperiodi$anno_prec.php"))

} # fine else if (controlla_anno($anno) == "NO")
echo "</form><br><hr width=\"95%\"><br>
<form method=\"post\" action=\"inizio.php\">
<br> ".mex("richiedi l'anno",$pag)."
<input type=\"text\" name=\"anno\" size=\"4\" maxlength=\"4\">
<input type=\"submit\" name=\"vai\" value=\"".mex("vai",$pag)."\"><br>
</form>";

} # fine else if ( is_file("dati/selectperiodi$anno.php"))

} # fine else if (is_file("dati/connessione_db.php") != true)

} # fine else if ($creaanno)

?>


</body>
</html>

==> php-residence_0.3.tar.gz: php-residence/inizio.php <==
<html>
<header>
<title> Pagina di entrata per php-residence </title>
</header>
<body bgcolor=#ffffff>
<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#################################################################################



include("./includes/funzioni.php");
$pag = "inizio.php";

if ($creaanno) {
include("./creaanno.php");
echo "<br> ".mex("Anno ",$pag).$anno.mex(" creato",$pag)."! <br><br>
<form method=\"post\" action=\"inizio.php?anno=$anno\">
<input type=\"submit\" name=\"ok\" value=\"OK\"><br>
</form>";

} # fine if ($creaanno)

else {

# Controllo se sonostati inseriti i dati permanenti.
if (is_file("dati/dati_connessione.php") != true) {
echo "
<center><font size=+2><b>Welcome to PHP-RESIDENCE.</b></font><br><br>
PHP-RESIDENCE version 0.3, Copyright (C) 2001-2002 Marco M. F. De Santis<br>
Php-residence comes with ABSOLUTELY NO WARRANTY; <br>for details see the file 
<a href=\"COPYING\">COPYING</a>. <br> This is free software, and you are 
welcome to redistribute it<br>
 under certain conditions; see the  file 
<a href=\"COPYING\">COPYING</a> for details.<br>
</center><hr width=\"95%\">
<br><br>
<form method=\"post\" action=\"creadb.php\">
Choose the language:
 <select name=\"lingua\">
<option value=\"en\">english</option>
<option value=\"ita\">italiano</option>
<!-- <option value=\"es\">espaol</option> -->
</select><br>
<input type=\"submit\" name=\"crealo\" value=\"create database\"><br>
</form>";
} # fine if (is_file("dati/connessione_db.php") != true)

else {

# Se non si specifica nessun anno uso l'attuale
if ( $anno == "" ) $anno = date("Y");

if ( is_file("dati/selectperiodi$anno.php")) {
//esiste l'anno richiesto
$anno_succ = $anno + 1;
echo "<br><center><font size=+2><strong>".mex("Men principale dell'anno",$pag)." 
$anno</font></strong> <br>";
echo "<P><br>
<form method=\"post\" action=\"prenota.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"prenota\" value=\"".mex("Inserisci una nuova prenotazione",$pag)."\"><br>
</form>
<form method=\"post\" action=\"tabella.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<table cellspacing=0 cellpadding=0><tr><td>
<input type=\"submit\" name=\"prenota\" value=\"".mex("Visualizza e modifica le prenotazioni",$pag)."\">
 ".mex("del mese di",$pag);
$mese_attuale = date("n");
for ($num1 = 1 ; $num1 <= 12 ; $num1++) {
$mese_invia[$num1] = "\"$num1\"";
if ($num1 == $mese_attuale) $mese_invia[$num1] .= " selected";
$mese_invia[$num1] .= ">";
} # fine for $num1
echo " <select name=\"mese\">
<option value=".$mese_invia[1].mex("Gennaio",$pag)."</option>
<option value=".$mese_invia[2].mex("Febbraio",$pag)."</option>
<option value=".$mese_invia[3].mex("Marzo",$pag)."</option>
<option value=".$mese_invia[4].mex("Aprile",$pag)."</option>
<option value=".$mese_invia[5].mex("Maggio",$pag)."</option>
<option value=".$mese_invia[6].mex("Giugno",$pag)."</option>
<option value=".$mese_invia[7].mex("Luglio",$pag)."</option>
<option value=".$mese_invia[8].mex("Agosto",$pag)."</option>
<option value=".$mese_invia[9].mex("Settembre",$pag)."</option>
<option value=".$mese_invia[10].mex("Ottobre",$pag)."</option>
<option value=".$mese_invia[11].mex("Novembre",$pag)."</option>
<option value=".$mese_invia[12].mex("Dicembre",$pag)."</option>
</select></td><td>
<input type=\"radio\" name=\"anno_succ\" value=\"NO\" checked>$anno<br>
<input type=\"radio\" name=\"anno_succ\" value=\"SI\">$anno_succ
</td></tr></table>
</form>
<form method=\"post\" action=\"visualizza_tabelle.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"visualizza\" value=\"".mex("Visualizza la tabella",$pag)."\">
 ".mex("con",$pag)."
<select name=\"tipo_tabella\">
<option value=\"prenotazioni\">".mex("tutte le prenotazioni",$pag)."</option>
<option value=\"costi\">".mex("le spese e le entrate",$pag)."</option>
<option value=\"periodi\">".mex("i periodi e le tariffe",$pag)."</option>
<option value=\"clienti\">".mex("tutti i clienti",$pag)."</option>
<option value=\"regole\">".mex("le regole di assegnazione",$pag)."</option>
<option value=\"appartamenti\">".mex("tutti gli appartamenti",$pag)."</option>
</select>
<br>
</form>
<form method=\"post\" action=\"clienti.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"clienti\" value=\"".mex("Inserisci o modifica i dati di un cliente",$pag)."\"><br>
</form>
<form method=\"post\" action=\"costi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"ins_costi\" value=\"".mex("Inserisci le spese e le entrate",$pag)."\"><br>
</form>
<form method=\"post\" action=\"disponibilita.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"con_dis\" value=\"".mex("Controlla la disponibilit",$pag)."\">
 ".mex("dal",$pag)." <select name=\"inizioperiodo\">";
include("./dati/selperiodimenu$anno.php");
echo "</select>
 ".mex("al",$pag)." <select name=\"fineperiodo\">";
include("./dati/selperiodimenu$anno.php");
echo "</select> (".mex("per",$pag)."
 <input type=\"text\" name=\"numpersone\" size=\"2\" maxlength=\"2\">
 ".mex("persone",$pag).")
</form>
<hr width=\"95%\">
<form method=\"post\" action=\"creaprezzi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"insprezzi\" value=\"".mex("Inserisci o modifica i prezzi",$pag)."\">
</form>
<form method=\"post\" action=\"crearegole.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"insregole\" value=\"".mex("Inserisci o modifica le regole di assegnazione",$pag)."\"><br>
</form>
<form method=\"post\" action=\"personalizza.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"insregole\" value=\"".mex("Configura e personalizza",$pag)."\"><br>
</form>
<form method=\"post\" action=\"inizio.php\">
".mex("richiedi l'anno",$pag)."
<input type=\"text\" name=\"anno\" size=\"4\" maxlength=\"4\">
<input type=\"submit\" name=\"vai\" value=\"".mex("vai",$pag)."\"><br>
</form>";


} # fine if ( is_dir($anno))

else {

# Non esiste l'anno richiesto

if (controlla_anno($anno) == "NO") echo mex("Il formato dell'anno richiesto  sbagliato",$pag).".<br>";
else {

echo "<br> ".mex("Non esiste l'anno ",$pag).$anno.mex(" nel database",$pag).". <br><br>
<form method=\"post\" action=\"inizio.php?anno=$anno\">
<input type=\"submit\" name=\"creaanno\" value=\"".mex("Crea l'anno",$pag)." $anno \">
 ".mex("con periodi",$pag).":<br>
<input type=\"radio\" name=\"tipo_periodi\" value=\"s\" checked>
".mex("settimanali",$pag)." (
 <select name=\"giorno_ini_fine\">
<option value=\"0\">".mex("Domenica",$pag)."</option>
<option value=\"1\">".mex("Luned",$pag)."</option>
<option value=\"2\">".mex("Marted",$pag)."</option>
<option value=\"3\">".mex("Mercoled",$pag)."</option>
<option value=\"4\">".mex("Gioved",$pag)."</option>
<option value=\"5\">".mex("Venerd",$pag)."</option>
<option value=\"6\" selected>".mex("Sabato",$pag)."</option>
</select> ".mex("come giorno di inizio/fine locazione",$pag).")<br>
<input type=\"radio\" name=\"tipo_periodi\" value=\"g\">
".mex("giornalieri",$pag)."<br>
".mex("e prenotazioni da",$pag)."
 <select name=\"mese_ini\">
<option value=\"1\" selected>".mex("Gennaio",$pag)."</option>
<option value=\"2\">".mex("Febbraio",$pag)."</option>
<option value=\"3\">".mex("Marzo",$pag)."</option>
<option value=\"4\">".mex("Aprile",$pag)."</option>
<option value=\"5\">".mex("Maggio",$pag)."</option>
<option value=\"6\">".mex("Giugno",$pag)."</option>
<option value=\"7\">".mex("Luglio",$pag)."</option>
<option value=\"8\">".mex("Agosto",$pag)."</option>
<option value=\"9\">".mex("Settembre",$pag)."</option>
<option value=\"10\">".mex("Ottobre",$pag)."</option>
<option value=\"11\">".mex("Novembre",$pag)."</option>
<option value=\"12\">".mex("Dicembre",$pag)."</option>
</select> ".mex("a",$pag)."
 <select name=\"mese_fine\">
<option value=\"1\">".mex("Gennaio",$pag)."</option>
<option value=\"2\">".mex("Febbraio",$pag)."</option>
<option value=\"3\">".mex("Marzo",$pag)."</option>
<option value=\"4\">".mex("Aprile",$pag)."</option>
<option value=\"5\">".mex("Maggio",$pag)."</option>
<option value=\"6\">".mex("Giugno",$pag)."</option>
<option value=\"7\">".mex("Luglio",$pag)."</option>
<option value=\"8\">".mex("Agosto",$pag)."</option>
<option value=\"9\">".mex("Settembre",$pag)."</option>
<option value=\"10\">".mex("Ottobre",$pag)."</option>
<option value=\"11\">".mex("Novembre",$pag)."</option>
<option value=\"12\" selected>".mex("Dicembre",$pag)."</option>
<option value=\"13\">".mex("Gen. anno successivo",$pag)."</option>
<option value=\"14\">".mex("Feb. anno successivo",$pag)."</option>
<option value=\"15\">".mex("Mar. anno successivo",$pag)."</option>
<option value=\"16\">".mex("Apr. anno successivo",$pag)."</option>
<option value=\"17\">".mex("Mag. anno successivo",$pag)."</option>
<option value=\"18\">".mex("Giu. anno successivo",$pag)."</option>
<option value=\"19\">".mex("Lug. anno successivo",$pag)."</option>
<option value=\"20\">".mex("Ago. anno successivo",$pag)."</option>
<option value=\"21\">".mex("Set. anno successivo",$pag)."</option>
<option value=\"22\">".mex("Ott. anno successivo",$pag)."</option>
<option value=\"23\">".mex("Nov. anno successivo",$pag)."</option>
<option value=\"24\">".mex("Dic. anno successivo",$pag)."</option>
<option value=\"25\">".mex("Gen. 2 anni successivi",$pag)."</option>
</select>.<br>";
$anno_prec = $anno -1;
if ( is_file("dati/selectperiodi$anno_prec.php")) {
echo "<input type=\"checkbox\" name=\"importa_anno_prec\" value=\"SI\" checked>
".mex("Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi) e 
regole d'assegnazione relative a quest'anno.",$pag);
} # fine if ( is_file("dati/selectperiodi$anno_prec.php"))

} # fine else if (controlla_anno($anno) == "NO")
echo "</form><br><hr width=\"95%\"><br>
<form method=\"post\" action=\"inizio.php\">
<br> ".mex("richiedi l'anno",$pag)."
<input type=\"text\" name=\"anno\" size=\"4\" maxlength=\"4\">
<input type=\"submit\" name=\"vai\" value=\"".mex("vai",$pag)."\"><br>
</form>";

} # fine else if ( is_file("dati/selectperiodi$anno.php"))

} # fine else if (is_file("dati/connessione_db.php") != true)

} # fine else if ($creaanno)

?>


</body>
</html>
